searchData={"items":[{"type":"module","title":"Liquex","doc":"# Liquex\n\nA [Liquid](https://shopify.github.io/liquid/) template parser for Elixir.\n\nLiquid template renderer for Elixir with 100% compatibility with the\n[Liquid](https://shopify.github.io/liquid/) gem by [Shopify](https://www.shopify.com/).\nIf you find that this library is not byte for byte equivalent to liquid, please\n[open an issue](https://github.com/markglenn/liquex/issues).","ref":"Liquex.html"},{"type":"module","title":"Installation - Liquex","doc":"The package is [available in Hex](https://hex.pm/packages/liquex) and can be installed\nby adding `liquex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:liquex, \"~> 0.13.0\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/liquex](https://hexdocs.pm/liquex).","ref":"Liquex.html#module-installation"},{"type":"module","title":"Basic Usage - Liquex","doc":"```elixir\niex> {:ok, template_ast} = Liquex.parse(\"Hello {{ name }}!\")\niex> {content, _context} = Liquex.render!(template_ast, %{\"name\" => \"World\"})\n\niex> content |> to_string()\n\"Hello World!\"\n```","ref":"Liquex.html#module-basic-usage"},{"type":"module","title":"Supported features - Liquex","doc":"Liquex is byte for byte, 100% compatible with the latest Liquid gem.","ref":"Liquex.html#module-supported-features"},{"type":"module","title":"Lazy variables - Liquex","doc":"Liquex allows resolver functions for variables that may require some extra\nwork to generate. For example, Shopify has variables for things like\navailable products. Pulling all products every time would be too expensive\nto do on every render. Instead, it would be better to lazily pull that\ninformation as needed.\n\nInstead of adding the product list to the context variable map, you can add\na function to the variable map. If a function is accessed in the variable\nmap, it is executed.\n\n```elixir\nproducts_resolver = fn _parent -> Product.all() end\n\nwith {:ok, document} <- Liquex.parse(\"There are {{ products.size }} products\"),\n    {result, _} <- Liquex.render!(document, %{products: products_resolver}) do\n  result\nend\n\n\"There are 5 products\"\n```","ref":"Liquex.html#module-lazy-variables"},{"type":"module","title":"Indifferent access - Liquex","doc":"By default, Liquex accesses your maps and structs that may have atom or\nstring (or other type) keys. Liquex will try a string key first. If that\nfails, it will fall back to using an atom keys.  This is similar to how\nRuby on Rails handles many of its hashes.\n\nThis allows you to pass in your structs without having to replace all your\nkeys with string keys.\n\n```elixir\niex> {:ok, template_ast} = Liquex.parse(\"Hello {{ name }}!\")\niex> {content, _context} = Liquex.render!(template_ast, %{name: \"World\"})\niex> content |> to_string()\n\"Hello World!\"\n```","ref":"Liquex.html#module-indifferent-access"},{"type":"module","title":"Caching - Liquex","doc":"Liquex has a built in cache used specifically for the render tag currently. When\nloading a partial/sub-template using the render tag, it will try pulling from\nthe cache associated with the context.\n\nBy default, caching is disabled, but you may use the built in ETS based cache by\nconfiguring it in your context.\n\n```elixir\n:ok = Liquex.Cache.SimpleCache.init()\ncontext = Context.new(%{...}, cache: Liquex.Cache.SimpleCache)\n```\n\nThe simple cache is by definition quite simple. To use a more complete caching\nsystem, such as [Cachex](https://github.com/whitfin/cachex), you can create a\nmodule that implements the `Liquex.Cache` behaviour.\n\nThe cache system is very early on. It is expected that it will also be used to\nmemoize some of the variables within your context.","ref":"Liquex.html#module-caching"},{"type":"module","title":"Custom filters - Liquex","doc":"Liquex contains the full suite of standard Liquid filters, but you may find that there are still\nfilters that you may want to add.\n\nLiquex supports adding your own custom filters to the render pipeline.  When creating the context\nfor the renderer, set the filter module to your own module.\n\n```elixir\ndefmodule CustomFilter do\n  # Import all the standard liquid filters\n  use Liquex.Filter\n\n  def scream(value, _), do: String.upcase(value) <> \"!\"\nend\n\ncontext = Liquex.Context.new(%{}, filter_module: CustomFilter)\n{:ok, template_ast} = Liquex.parse(\"{{'Hello World' | scream}}\"\n\n{result, _} = Liquex.render!(template_ast, context)\nresult |> to_string()\n\niex> \"HELLO WORLD!\"\n```","ref":"Liquex.html#module-custom-filters"},{"type":"module","title":"Custom tags - Liquex","doc":"One of the strong points for Liquex is that the tag parser can be extended to support non-standard\ntags. For example, Liquid used internally for the Shopify site includes a large range of tags that\nare not supported by the base Ruby gem.  These tags could also be added to Liquex by extending the\nliquid parser.\n\n```elixir\ndefmodule CustomTag do\n  @moduledoc false\n\n  @behaviour Liquex.Tag\n\n  import NimbleParsec\n\n  @impl true\n  # Parse < >\n  def parse() do\n    text =\n      lookahead_not(string(\">>\"))\n      |> utf8_char([])\n      |> times(min: 1)\n      |> reduce({Kernel, :to_string, []})\n      |> tag(:text)\n\n    ignore(string(\"<<\"))\n    |> optional(text)\n    |> ignore(string(\">>\"))\n  end\n\n  @impl true\n  def render(contents, context) do\n    {result, context} = Liquex.render!(contents, context)\n    {[\"Custom Tag: \", result], context}\n  end\nend\n\ndefmodule CustomParser do\n  use Liquex.Parser, tags: [CustomTag]\nend\n\niex> document = Liquex.parse!(\"< >\", CustomParser)\niex> {result, _} = Liquex.render!(document, context)\niex> result |> to_string()\n\"Custom Tag: Hello World!\"\n```","ref":"Liquex.html#module-custom-tags"},{"type":"module","title":"Deviations from original Liquid gem - Liquex","doc":"#","ref":"Liquex.html#module-deviations-from-original-liquid-gem"},{"type":"module","title":"Whitespace is kept in empty blocks - Liquex","doc":"For performance reasons, whitespace is kept within empty blocks such as\nfor/if/unless. The liquid gem checks for \"blank\" renders and throws them away.\nInstead, we continue to use IO lists to combine the output and don't check for\nblank results to avoid too many conversions to strings.  Since Liquid is mostly\nused for whitespace agnostic documents, this seemed like a decent tradeoff. If\nyou need better whitespace control, use `{%-`, `{{-`, `-%}`, and `-}}`.","ref":"Liquex.html#module-whitespace-is-kept-in-empty-blocks"},{"type":"function","title":"Liquex.parse/2","doc":"Parses a liquid `template` string using the given `parser`.\n\nReturns a Liquex AST document or the parser error","ref":"Liquex.html#parse/2"},{"type":"function","title":"Liquex.parse!/2","doc":"Parses a liquid `template` string using the given `parser`.\n\nReturns a Liquex AST document or raises an exception.  See also `parse/2`","ref":"Liquex.html#parse!/2"},{"type":"function","title":"Liquex.render/2","doc":"","ref":"Liquex.html#render/2"},{"type":"function","title":"Liquex.render!/2","doc":"Render a Liquex AST `document` with the given `context`","ref":"Liquex.html#render!/2"},{"type":"type","title":"Liquex.document_t/0","doc":"","ref":"Liquex.html#t:document_t/0"},{"type":"module","title":"Liquex.BlankFileSystem","doc":"Default file system that throws an error when trying to call render within a\ntemplate.","ref":"Liquex.BlankFileSystem.html"},{"type":"behaviour","title":"Liquex.Cache","doc":"Caching behaviour attached to a `Liquex.Context`.\n\nCurrently, caching is only used for partial loading in render tags.","ref":"Liquex.Cache.html"},{"type":"callback","title":"Liquex.Cache.fetch/2","doc":"Fetch a value from cache. If the value doesn't exist, run the given function\nand store the results within the cache.","ref":"Liquex.Cache.html#c:fetch/2"},{"type":"type","title":"Liquex.Cache.key/0","doc":"","ref":"Liquex.Cache.html#t:key/0"},{"type":"type","title":"Liquex.Cache.value/0","doc":"","ref":"Liquex.Cache.html#t:value/0"},{"type":"module","title":"Liquex.Cache.DisabledCache","doc":"Default caching system for Liquex. Always runs the given function and never\nstores the results.","ref":"Liquex.Cache.DisabledCache.html"},{"type":"module","title":"Liquex.Cache.SimpleCache","doc":"Basic caching system that uses ETS.","ref":"Liquex.Cache.SimpleCache.html"},{"type":"function","title":"Liquex.Cache.SimpleCache.init/0","doc":"","ref":"Liquex.Cache.SimpleCache.html#init/0"},{"type":"protocol","title":"Liquex.Collection","doc":"","ref":"Liquex.Collection.html"},{"type":"function","title":"Liquex.Collection.limit/2","doc":"","ref":"Liquex.Collection.html#limit/2"},{"type":"function","title":"Liquex.Collection.offset/2","doc":"","ref":"Liquex.Collection.html#offset/2"},{"type":"function","title":"Liquex.Collection.reverse/1","doc":"","ref":"Liquex.Collection.html#reverse/1"},{"type":"function","title":"Liquex.Collection.sort/1","doc":"","ref":"Liquex.Collection.html#sort/1"},{"type":"function","title":"Liquex.Collection.sort/2","doc":"","ref":"Liquex.Collection.html#sort/2"},{"type":"function","title":"Liquex.Collection.sort_case_insensitive/1","doc":"","ref":"Liquex.Collection.html#sort_case_insensitive/1"},{"type":"function","title":"Liquex.Collection.sort_case_insensitive/2","doc":"","ref":"Liquex.Collection.html#sort_case_insensitive/2"},{"type":"function","title":"Liquex.Collection.to_enumerable/1","doc":"","ref":"Liquex.Collection.html#to_enumerable/1"},{"type":"function","title":"Liquex.Collection.where/2","doc":"","ref":"Liquex.Collection.html#where/2"},{"type":"function","title":"Liquex.Collection.where/3","doc":"","ref":"Liquex.Collection.html#where/3"},{"type":"type","title":"Liquex.Collection.t/0","doc":"","ref":"Liquex.Collection.html#t:t/0"},{"type":"module","title":"Liquex.Context","doc":"Context keeps the variable stack and resolves variables, as well as keywords.\nIt also keeps configuration information needed to render a Liquid template,\nsuch as filters and the file system.\n\nVariables are stored within a few different contexts which each have their own\nusage and meaning.\n\n### :environment\n\nThe environment stores the top level variables defined outside of the liquid\ntemplates. These are variables you want to predefine before rendering the\ntemplates. Note: these variables are not accessible within nested `render` tags.\n\n### :static_environment\n\nThe static environment is similar to the base environment. The difference is\nthat it has a lower priority for reading than the environment and the\nvariables defined in this context are accessible within nested `render` tags.\n\nUse the static environment if you want global variables accessible across all\nrender tags.\n\n### :scope\n\nThe scope is a stack of environments that keep track of variables within\nvarious scopes. For example, when entering a for loop, it creates a new scope\nand pushes it onto the stack. When exiting the for loop, all variables defined\nwithin that scope are removed.\n\nScopes have the highest precedence of all the different locations that store\nvariables.","ref":"Liquex.Context.html"},{"type":"module","title":"Examples - Liquex.Context","doc":"iex> context = Liquex.Context.new(%{hello: \"environment\"})\n    iex> Access.get(context, \"hello\")\n    \"environment\"\n\n    iex> context = Liquex.Context.new(%{}, scope: %{hello: \"scope\"})\n    iex> Access.get(context, \"hello\")\n    \"scope\"\n\n    iex> context = Liquex.Context.new(%{}, static_environment: %{hello: \"static environment\"})\n    iex> Access.get(context, \"hello\")\n    \"static environment\"","ref":"Liquex.Context.html#module-examples"},{"type":"function","title":"Liquex.Context.assign/3","doc":"Assign a new variable to the `context`\n\nSet a variable named `key` with the given `value` in the current context","ref":"Liquex.Context.html#assign/3"},{"type":"function","title":"Liquex.Context.assign_global/3","doc":"","ref":"Liquex.Context.html#assign_global/3"},{"type":"function","title":"Liquex.Context.fetch/2","doc":"Look up variable within the current scope. If the scope does not define the\nvariable, it is then looked up in the environment. Lastly, if that fails, it\nfalls back to the static environment.\n\nAll variable look ups are indifferent to the key being a string or an atom.\nEither or can be used to save and store the variables.","ref":"Liquex.Context.html#fetch/2"},{"type":"function","title":"Liquex.Context.get/3","doc":"","ref":"Liquex.Context.html#get/3"},{"type":"function","title":"Liquex.Context.get_and_update/3","doc":"","ref":"Liquex.Context.html#get_and_update/3"},{"type":"function","title":"Liquex.Context.new/2","doc":"Create a new `Context` using predefined `variables` map\n\nReturns a new context to store the current state of a liquid template during\nthe render phase.","ref":"Liquex.Context.html#new/2"},{"type":"function","title":"Options - Liquex.Context.new/2","doc":"* :static_environment - An unchanging environment scope also accessible from\n    nested render tags.\n\n  * :scope - Initial scope with variables defined as if they were set\n    within the liquid template.\n\n  * :filter_module - Module that will be used for filtering\n\n  * :file_system - File loading module\n\n  * :cache_prefix - Prefix for cache keys, if you need separate partial caches\n    for multitenancy or otherwise","ref":"Liquex.Context.html#new/2-options"},{"type":"function","title":"Liquex.Context.new_isolated_subscope/2","doc":"Create a new context inheriting static environment and options","ref":"Liquex.Context.html#new_isolated_subscope/2"},{"type":"function","title":"Liquex.Context.pop/2","doc":"","ref":"Liquex.Context.html#pop/2"},{"type":"function","title":"Liquex.Context.pop_scope/1","doc":"Pop the current scope off the scope stack and throw it away","ref":"Liquex.Context.html#pop_scope/1"},{"type":"function","title":"Liquex.Context.push_error/2","doc":"Assign an error to the error logs","ref":"Liquex.Context.html#push_error/2"},{"type":"function","title":"Liquex.Context.push_scope/2","doc":"Push a new scope onto the scope stack","ref":"Liquex.Context.html#push_scope/2"},{"type":"type","title":"Liquex.Context.t/0","doc":"","ref":"Liquex.Context.html#t:t/0"},{"type":"protocol","title":"Liquex.FileSystem","doc":"Behaviour for file system access used by the `render` tag.","ref":"Liquex.FileSystem.html"},{"type":"function","title":"Liquex.FileSystem.read_template_file/2","doc":"Read a template from the filesystem","ref":"Liquex.FileSystem.html#read_template_file/2"},{"type":"type","title":"Liquex.FileSystem.t/0","doc":"All the types that implement this protocol.","ref":"Liquex.FileSystem.html#t:t/0"},{"type":"behaviour","title":"Liquex.Filter","doc":"Contains all the basic filters for Liquid","ref":"Liquex.Filter.html"},{"type":"function","title":"Liquex.Filter.abs/2","doc":"Returns the absolute value of `value`.","ref":"Liquex.Filter.html#abs/2"},{"type":"function","title":"Examples - Liquex.Filter.abs/2","doc":"iex> Liquex.Filter.abs(-1, %{})\n    1\n\n    iex> Liquex.Filter.abs(1, %{})\n    1\n\n    iex> Liquex.Filter.abs(\"-1.1\", %{})\n    1.1","ref":"Liquex.Filter.html#abs/2-examples"},{"type":"function","title":"Liquex.Filter.append/3","doc":"Appends `text` to the end of `value`","ref":"Liquex.Filter.html#append/3"},{"type":"function","title":"Examples - Liquex.Filter.append/3","doc":"iex> Liquex.Filter.append(\"myfile\", \".html\", %{})\n    \"myfile.html\"","ref":"Liquex.Filter.html#append/3-examples"},{"type":"callback","title":"Liquex.Filter.apply/3","doc":"","ref":"Liquex.Filter.html#c:apply/3"},{"type":"function","title":"Liquex.Filter.apply/4","doc":"","ref":"Liquex.Filter.html#apply/4"},{"type":"function","title":"Liquex.Filter.at_least/3","doc":"Sets a minimum value","ref":"Liquex.Filter.html#at_least/3"},{"type":"function","title":"Examples - Liquex.Filter.at_least/3","doc":"iex> Liquex.Filter.at_least(3, 5, %{})\n    5\n\n    iex> Liquex.Filter.at_least(5, 3, %{})\n    5\n\n    iex> Liquex.Filter.at_least(\"5\", \"3\", %{})\n    5","ref":"Liquex.Filter.html#at_least/3-examples"},{"type":"function","title":"Liquex.Filter.at_most/3","doc":"Sets a maximum value","ref":"Liquex.Filter.html#at_most/3"},{"type":"function","title":"Examples - Liquex.Filter.at_most/3","doc":"iex> Liquex.Filter.at_most(4, 5, %{})\n    4\n\n    iex> Liquex.Filter.at_most(4, 3, %{})\n    3\n\n    iex> Liquex.Filter.at_most(\"4\", \"3\", %{})\n    3","ref":"Liquex.Filter.html#at_most/3-examples"},{"type":"function","title":"Liquex.Filter.capitalize/2","doc":"Capitalizes a string","ref":"Liquex.Filter.html#capitalize/2"},{"type":"function","title":"Examples - Liquex.Filter.capitalize/2","doc":"iex> Liquex.Filter.capitalize(\"title\", %{})\n    \"Title\"\n\n    iex> Liquex.Filter.capitalize(\"my great title\", %{})\n    \"My great title\"","ref":"Liquex.Filter.html#capitalize/2-examples"},{"type":"function","title":"Liquex.Filter.ceil/2","doc":"Rounds `value` up to the nearest whole number. Liquid tries to convert the input to a number before the filter is applied.","ref":"Liquex.Filter.html#ceil/2"},{"type":"function","title":"Examples - Liquex.Filter.ceil/2","doc":"iex> Liquex.Filter.ceil(1.2, %{})\n    2\n\n    iex> Liquex.Filter.ceil(2.0, %{})\n    2\n\n    iex> Liquex.Filter.ceil(183.357, %{})\n    184\n\n    iex> Liquex.Filter.ceil(\"3.5\", %{})\n    4","ref":"Liquex.Filter.html#ceil/2-examples"},{"type":"function","title":"Liquex.Filter.compact/2","doc":"Removes any nil values from an array.","ref":"Liquex.Filter.html#compact/2"},{"type":"function","title":"Examples - Liquex.Filter.compact/2","doc":"iex> Liquex.Filter.compact([1, 2, nil, 3], %{})\n    [1,2,3]\n\n    iex> Liquex.Filter.compact([1, 2, 3], %{})\n    [1,2,3]","ref":"Liquex.Filter.html#compact/2-examples"},{"type":"function","title":"Liquex.Filter.concat/3","doc":"Concatenates (joins together) multiple arrays. The resulting array contains all the items","ref":"Liquex.Filter.html#concat/3"},{"type":"function","title":"Examples - Liquex.Filter.concat/3","doc":"iex> Liquex.Filter.concat([1,2], [3,4], %{})\n    [1,2,3,4]","ref":"Liquex.Filter.html#concat/3-examples"},{"type":"function","title":"Liquex.Filter.date/3","doc":"Converts `value` timestamp into another date `format`.\n\nThe format for this syntax is the same as strftime. The input uses the same format as Ruby’s Time.parse.","ref":"Liquex.Filter.html#date/3"},{"type":"function","title":"Examples - Liquex.Filter.date/3","doc":"iex> Liquex.Filter.date(~D[2000-01-01], \"%m/%d/%Y\", %{})\n    \"01/01/2000\"\n\n    iex> Liquex.Filter.date(\"2000-01-01\", \"%m/%d/%Y\", %{})\n    \"01/01/2000\"\n\n    iex> Liquex.Filter.date(\"January 1, 2000\", \"%m/%d/%Y\", %{})\n    \"01/01/2000\"\n\n    iex> Liquex.Filter.date(\"1/2/2000\", \"%m/%d/%Y\", %{})\n    \"01/02/2000\"\n\n    iex> Liquex.Filter.date(\"March 14, 2016\", \"%b %d, %y\", %{})\n    \"Mar 14, 16\"","ref":"Liquex.Filter.html#date/3-examples"},{"type":"function","title":"Liquex.Filter.default/3","doc":"Allows you to specify a fallback in case a value doesn’t exist. default will show its value\nif the left side is nil, false, or empty.","ref":"Liquex.Filter.html#default/3"},{"type":"function","title":"Examples - Liquex.Filter.default/3","doc":"iex> Liquex.Filter.default(\"1.99\", \"2.99\", %{})\n    \"1.99\"\n\n    iex> Liquex.Filter.default(\"\", \"2.99\", %{})\n    \"2.99\"","ref":"Liquex.Filter.html#default/3-examples"},{"type":"function","title":"Liquex.Filter.divided_by/3","doc":"Divides a number by another number.","ref":"Liquex.Filter.html#divided_by/3"},{"type":"function","title":"Examples - Liquex.Filter.divided_by/3","doc":"The result is rounded down to the nearest integer (that is, the floor) if the divisor is an integer.\n\n    iex> Liquex.Filter.divided_by(16, 4, %{})\n    4\n\n    iex> Liquex.Filter.divided_by(5, 3, %{})\n    1\n\n    iex> Liquex.Filter.divided_by(20, 7.0, %{})\n    2.857142857142857","ref":"Liquex.Filter.html#divided_by/3-examples"},{"type":"function","title":"Liquex.Filter.downcase/2","doc":"Makes each character in a string lowercase. It has no effect on strings\nwhich are already all lowercase.","ref":"Liquex.Filter.html#downcase/2"},{"type":"function","title":"Examples - Liquex.Filter.downcase/2","doc":"iex> Liquex.Filter.downcase(\"Parker Moore\", %{})\n    \"parker moore\"\n\n    iex> Liquex.Filter.downcase(\"apple\", %{})\n    \"apple\"","ref":"Liquex.Filter.html#downcase/2-examples"},{"type":"function","title":"Liquex.Filter.escape/2","doc":"Escapes a string by replacing characters with escape sequences (so that the string can\nbe used in a URL, for example). It doesn’t change strings that don’t have anything to\nescape.","ref":"Liquex.Filter.html#escape/2"},{"type":"function","title":"Examples - Liquex.Filter.escape/2","doc":"iex> Liquex.Filter.escape(\"Have you read 'James & the Giant Peach'?\", %{})\n    \"Have you read &#39;James &amp; the Giant Peach&#39;?\"\n\n    iex> Liquex.Filter.escape(\"Tetsuro Takara\", %{})\n    \"Tetsuro Takara\"","ref":"Liquex.Filter.html#escape/2-examples"},{"type":"function","title":"Liquex.Filter.escape_once/2","doc":"Escapes a string by replacing characters with escape sequences (so that the string can\nbe used in a URL, for example). It doesn’t change strings that don’t have anything to\nescape.","ref":"Liquex.Filter.html#escape_once/2"},{"type":"function","title":"Examples - Liquex.Filter.escape_once/2","doc":"iex> Liquex.Filter.escape_once(\"1 &lt; 2 &amp; 3\", %{})\n    \"1 &lt; 2 &amp; 3\"","ref":"Liquex.Filter.html#escape_once/2-examples"},{"type":"function","title":"Liquex.Filter.filter_name/1","doc":"","ref":"Liquex.Filter.html#filter_name/1"},{"type":"function","title":"Liquex.Filter.first/2","doc":"Returns the first item of an array.","ref":"Liquex.Filter.html#first/2"},{"type":"function","title":"Examples - Liquex.Filter.first/2","doc":"iex> Liquex.Filter.first([1, 2, 3], %{})\n    1\n\n    iex> Liquex.Filter.first([], %{})\n    nil","ref":"Liquex.Filter.html#first/2-examples"},{"type":"function","title":"Liquex.Filter.floor/2","doc":"Rounds the input down to the nearest whole number. Liquid tries to convert the input to a\nnumber before the filter is applied.","ref":"Liquex.Filter.html#floor/2"},{"type":"function","title":"Examples - Liquex.Filter.floor/2","doc":"iex> Liquex.Filter.floor(1.2, %{})\n    1\n\n    iex> Liquex.Filter.floor(2.0, %{})\n    2","ref":"Liquex.Filter.html#floor/2-examples"},{"type":"function","title":"Liquex.Filter.join/3","doc":"Combines the items in `values` into a single string using `joiner` as a separator.","ref":"Liquex.Filter.html#join/3"},{"type":"function","title":"Examples - Liquex.Filter.join/3","doc":"iex> Liquex.Filter.join(~w(John Paul George Ringo), \" and \", %{})\n    \"John and Paul and George and Ringo\"","ref":"Liquex.Filter.html#join/3-examples"},{"type":"function","title":"Liquex.Filter.last/2","doc":"Returns the last item of `arr`.","ref":"Liquex.Filter.html#last/2"},{"type":"function","title":"Examples - Liquex.Filter.last/2","doc":"iex> Liquex.Filter.last([1, 2, 3], %{})\n    3\n\n    iex> Liquex.Filter.first([], %{})\n    nil","ref":"Liquex.Filter.html#last/2-examples"},{"type":"function","title":"Liquex.Filter.lstrip/2","doc":"Removes all whitespace (tabs, spaces, and newlines) from the left side of a string.\nIt does not affect spaces between words.","ref":"Liquex.Filter.html#lstrip/2"},{"type":"function","title":"Examples - Liquex.Filter.lstrip/2","doc":"iex> Liquex.Filter.lstrip(\"          So much room for activities!          \", %{})\n    \"So much room for activities!          \"","ref":"Liquex.Filter.html#lstrip/2-examples"},{"type":"function","title":"Liquex.Filter.map/3","doc":"Creates an array (`arr`) of values by extracting the values of a named property from another object (`key`).","ref":"Liquex.Filter.html#map/3"},{"type":"function","title":"Examples - Liquex.Filter.map/3","doc":"iex> Liquex.Filter.map([%{\"a\" => 1}, %{\"a\" => 2, \"b\" => 1}], \"a\", %{})\n    [1, 2]","ref":"Liquex.Filter.html#map/3-examples"},{"type":"function","title":"Liquex.Filter.minus/3","doc":"Subtracts a number from another number.","ref":"Liquex.Filter.html#minus/3"},{"type":"function","title":"Examples - Liquex.Filter.minus/3","doc":"iex> Liquex.Filter.minus(4, 2, %{})\n    2\n\n    iex> Liquex.Filter.minus(183.357, 12, %{})\n    171.357","ref":"Liquex.Filter.html#minus/3-examples"},{"type":"function","title":"Liquex.Filter.modulo/3","doc":"Returns the remainder of a division operation.","ref":"Liquex.Filter.html#modulo/3"},{"type":"function","title":"Examples - Liquex.Filter.modulo/3","doc":"iex> Liquex.Filter.modulo(3, 2, %{})\n    1\n\n    iex> Liquex.Filter.modulo(183.357, 12, %{})\n    3.357","ref":"Liquex.Filter.html#modulo/3-examples"},{"type":"function","title":"Liquex.Filter.newline_to_br/2","doc":"Replaces every newline (\n) in a string with an HTML line break ( ).","ref":"Liquex.Filter.html#newline_to_br/2"},{"type":"function","title":"Examples - Liquex.Filter.newline_to_br/2","doc":"iex> Liquex.Filter.newline_to_br(\"\\nHello\\nthere\\n\", %{})\n    \" \\nHello \\nthere \\n\"","ref":"Liquex.Filter.html#newline_to_br/2-examples"},{"type":"function","title":"Liquex.Filter.plus/3","doc":"Adds a number to another number.","ref":"Liquex.Filter.html#plus/3"},{"type":"function","title":"Examples - Liquex.Filter.plus/3","doc":"iex> Liquex.Filter.plus(4, 2, %{})\n    6\n\n    iex> Liquex.Filter.plus(183.357, 12, %{})\n    195.357","ref":"Liquex.Filter.html#plus/3-examples"},{"type":"function","title":"Liquex.Filter.prepend/3","doc":"Adds the specified string to the beginning of another string.","ref":"Liquex.Filter.html#prepend/3"},{"type":"function","title":"Examples - Liquex.Filter.prepend/3","doc":"iex> Liquex.Filter.prepend(\"apples, oranges, and bananas\", \"Some fruit: \", %{})\n    \"Some fruit: apples, oranges, and bananas\"\n\n    iex> Liquex.Filter.prepend(\"/index.html\", \"example.com\", %{})\n    \"example.com/index.html\"","ref":"Liquex.Filter.html#prepend/3-examples"},{"type":"function","title":"Liquex.Filter.remove/3","doc":"Removes every occurrence of the specified substring from a string.","ref":"Liquex.Filter.html#remove/3"},{"type":"function","title":"Examples - Liquex.Filter.remove/3","doc":"iex> Liquex.Filter.remove(\"I strained to see the train through the rain\", \"rain\", %{})\n    \"I sted to see the t through the \"","ref":"Liquex.Filter.html#remove/3-examples"},{"type":"function","title":"Liquex.Filter.remove_first/3","doc":"Removes every occurrence of the specified substring from a string.","ref":"Liquex.Filter.html#remove_first/3"},{"type":"function","title":"Examples - Liquex.Filter.remove_first/3","doc":"iex> Liquex.Filter.remove_first(\"I strained to see the train through the rain\", \"rain\", %{})\n    \"I sted to see the train through the rain\"","ref":"Liquex.Filter.html#remove_first/3-examples"},{"type":"function","title":"Liquex.Filter.replace/4","doc":"Replaces every occurrence of the first argument in a string with the second argument.","ref":"Liquex.Filter.html#replace/4"},{"type":"function","title":"Examples - Liquex.Filter.replace/4","doc":"iex> Liquex.Filter.replace(\"Take my protein pills and put my helmet on\", \"my\", \"your\", %{})\n    \"Take your protein pills and put your helmet on\"","ref":"Liquex.Filter.html#replace/4-examples"},{"type":"function","title":"Liquex.Filter.replace_first/4","doc":"Replaces only the first occurrence of the first argument in a string with the second argument.","ref":"Liquex.Filter.html#replace_first/4"},{"type":"function","title":"Examples - Liquex.Filter.replace_first/4","doc":"iex> Liquex.Filter.replace_first(\"Take my protein pills and put my helmet on\", \"my\", \"your\", %{})\n    \"Take your protein pills and put my helmet on\"","ref":"Liquex.Filter.html#replace_first/4-examples"},{"type":"function","title":"Liquex.Filter.reverse/2","doc":"Reverses the order of the items in an array. reverse cannot reverse a string.","ref":"Liquex.Filter.html#reverse/2"},{"type":"function","title":"Examples - Liquex.Filter.reverse/2","doc":"iex> Liquex.Filter.reverse(~w(apples oranges peaches plums), %{})\n    [\"plums\", \"peaches\", \"oranges\", \"apples\"]","ref":"Liquex.Filter.html#reverse/2-examples"},{"type":"function","title":"Liquex.Filter.round/3","doc":"Rounds a number to the nearest integer or, if a number is passed as an argument, to that number of decimal places.","ref":"Liquex.Filter.html#round/3"},{"type":"function","title":"Examples - Liquex.Filter.round/3","doc":"iex> Liquex.Filter.round(1, %{})\n    1\n\n    iex> Liquex.Filter.round(1.2, %{})\n    1\n\n    iex> Liquex.Filter.round(2.7, %{})\n    3\n\n    iex> Liquex.Filter.round(183.357, 2, %{})\n    183.36\n\n    iex> Liquex.Filter.round(183.357, \"invalid\", %{})\n    183\n\n    iex> Liquex.Filter.round(183.357, 0, %{})\n    183\n\n    iex> Liquex.Filter.round(183.357, -1, %{})\n    183","ref":"Liquex.Filter.html#round/3-examples"},{"type":"function","title":"Liquex.Filter.rstrip/2","doc":"Removes all whitespace (tabs, spaces, and newlines) from the right side of a string.\nIt does not affect spaces between words.","ref":"Liquex.Filter.html#rstrip/2"},{"type":"function","title":"Examples - Liquex.Filter.rstrip/2","doc":"iex> Liquex.Filter.rstrip(\"          So much room for activities!          \", %{})\n    \"          So much room for activities!\"","ref":"Liquex.Filter.html#rstrip/2-examples"},{"type":"function","title":"Liquex.Filter.size/2","doc":"Returns the number of characters in a string or the number of items in an array.","ref":"Liquex.Filter.html#size/2"},{"type":"function","title":"Examples - Liquex.Filter.size/2","doc":"iex> Liquex.Filter.size(\"Ground control to Major Tom.\", %{})\n    28\n\n    iex> Liquex.Filter.size(~w(apples oranges peaches plums), %{})\n    4","ref":"Liquex.Filter.html#size/2-examples"},{"type":"function","title":"Liquex.Filter.slice/4","doc":"Returns a substring of 1 character beginning at the index specified by the\nfirst argument. An optional second argument specifies the length of the\nsubstring to be returned.","ref":"Liquex.Filter.html#slice/4"},{"type":"function","title":"Examples - Liquex.Filter.slice/4","doc":"iex> Liquex.Filter.slice(\"Liquid\", 0, %{})\n    \"L\"\n\n    iex> Liquex.Filter.slice(\"Liquid\", 2, %{})\n    \"q\"\n\n    iex> Liquex.Filter.slice(\"Liquid\", 2, 5, %{})\n    \"quid\"\n\nIf the first argument is a negative number, the indices are counted from\nthe end of the string:","ref":"Liquex.Filter.html#slice/4-examples"},{"type":"function","title":"Examples - Liquex.Filter.slice/4","doc":"iex> Liquex.Filter.slice(\"Liquid\", -3, 2, %{})\n    \"ui\"","ref":"Liquex.Filter.html#slice/4-examples"},{"type":"function","title":"Liquex.Filter.sort/2","doc":"Sorts items in an array in case-sensitive order.","ref":"Liquex.Filter.html#sort/2"},{"type":"function","title":"Examples - Liquex.Filter.sort/2","doc":"iex> Liquex.Filter.sort([\"zebra\", \"octopus\", \"giraffe\", \"Sally Snake\"], %{})\n    [\"Sally Snake\", \"giraffe\", \"octopus\", \"zebra\"]","ref":"Liquex.Filter.html#sort/2-examples"},{"type":"function","title":"Liquex.Filter.sort/3","doc":"","ref":"Liquex.Filter.html#sort/3"},{"type":"function","title":"Liquex.Filter.sort_natural/2","doc":"Sorts items in an array in case-insensitive order.","ref":"Liquex.Filter.html#sort_natural/2"},{"type":"function","title":"Examples - Liquex.Filter.sort_natural/2","doc":"iex> Liquex.Filter.sort_natural([\"zebra\", \"octopus\", \"giraffe\", \"Sally Snake\"], %{})\n    [\"giraffe\", \"octopus\", \"Sally Snake\", \"zebra\"]","ref":"Liquex.Filter.html#sort_natural/2-examples"},{"type":"function","title":"Liquex.Filter.sort_natural/3","doc":"","ref":"Liquex.Filter.html#sort_natural/3"},{"type":"function","title":"Liquex.Filter.split/3","doc":"Divides a string into an array using the argument as a separator. split is\ncommonly used to convert comma-separated items from a string to an array.","ref":"Liquex.Filter.html#split/3"},{"type":"function","title":"Examples - Liquex.Filter.split/3","doc":"iex> Liquex.Filter.split(\"John, Paul, George, Ringo\", \", \", %{})\n    [\"John\", \"Paul\", \"George\", \"Ringo\"]","ref":"Liquex.Filter.html#split/3-examples"},{"type":"function","title":"Liquex.Filter.strip/2","doc":"Removes all whitespace (tabs, spaces, and newlines) from both the left and\nright side of a string. It does not affect spaces between words.","ref":"Liquex.Filter.html#strip/2"},{"type":"function","title":"Examples - Liquex.Filter.strip/2","doc":"iex> Liquex.Filter.strip(\"          So much room for activities!          \", %{})\n    \"So much room for activities!\"","ref":"Liquex.Filter.html#strip/2-examples"},{"type":"function","title":"Liquex.Filter.strip_html/2","doc":"Removes any HTML tags from a string.","ref":"Liquex.Filter.html#strip_html/2"},{"type":"function","title":"Examples - Liquex.Filter.strip_html/2","doc":"iex> Liquex.Filter.strip_html(\"Have  you  read  Ulysses ?\", %{})\n    \"Have you read Ulysses?\"","ref":"Liquex.Filter.html#strip_html/2-examples"},{"type":"function","title":"Liquex.Filter.strip_newlines/2","doc":"Removes any newline characters (line breaks) from a string.","ref":"Liquex.Filter.html#strip_newlines/2"},{"type":"function","title":"Examples - Liquex.Filter.strip_newlines/2","doc":"iex> Liquex.Filter.strip_newlines(\"Hello\\nthere\", %{})\n    \"Hellothere\"","ref":"Liquex.Filter.html#strip_newlines/2-examples"},{"type":"function","title":"Liquex.Filter.times/3","doc":"Multiplies a number by another number.","ref":"Liquex.Filter.html#times/3"},{"type":"function","title":"Examples - Liquex.Filter.times/3","doc":"iex> Liquex.Filter.times(3, 4, %{})\n    12\n\n    iex> Liquex.Filter.times(24, 7, %{})\n    168\n\n    iex> Liquex.Filter.times(183.357, 12, %{})\n    2200.284","ref":"Liquex.Filter.html#times/3-examples"},{"type":"function","title":"Liquex.Filter.truncate/4","doc":"Shortens a string down to the number of characters passed as an argument. If\nthe specified number of characters is less than the length of the string, an\nellipsis (…) is appended to the string and is included in the character\ncount.","ref":"Liquex.Filter.html#truncate/4"},{"type":"function","title":"Examples - Liquex.Filter.truncate/4","doc":"iex> Liquex.Filter.truncate(\"Ground control to Major Tom.\", 20, %{})\n    \"Ground control to...\"\n\n    iex> Liquex.Filter.truncate(\"Ground control to Major Tom.\", 25, \", and so on\", %{})\n    \"Ground control, and so on\"\n\n    iex> Liquex.Filter.truncate(\"Ground control to Major Tom.\", 20, \"\", %{})\n    \"Ground control to Ma\"","ref":"Liquex.Filter.html#truncate/4-examples"},{"type":"function","title":"Liquex.Filter.truncatewords/4","doc":"Shortens a string down to the number of characters passed as an argument. If\nthe specified number of characters is less than the length of the string, an\nellipsis (…) is appended to the string and is included in the character\ncount.","ref":"Liquex.Filter.html#truncatewords/4"},{"type":"function","title":"Examples - Liquex.Filter.truncatewords/4","doc":"iex> Liquex.Filter.truncatewords(\"Ground control to Major Tom.\", 3, %{})\n    \"Ground control to...\"\n\n    iex> Liquex.Filter.truncatewords(\"Ground control to Major Tom.\", 3, \"--\", %{})\n    \"Ground control to--\"\n\n    iex> Liquex.Filter.truncatewords(\"Ground control to Major Tom.\", 3, \"\", %{})\n    \"Ground control to\"","ref":"Liquex.Filter.html#truncatewords/4-examples"},{"type":"function","title":"Liquex.Filter.uniq/2","doc":"Removes any duplicate elements in an array.","ref":"Liquex.Filter.html#uniq/2"},{"type":"function","title":"Examples - Liquex.Filter.uniq/2","doc":"iex> Liquex.Filter.uniq(~w(ants bugs bees bugs ants), %{})\n    [\"ants\", \"bugs\", \"bees\"]","ref":"Liquex.Filter.html#uniq/2-examples"},{"type":"function","title":"Liquex.Filter.upcase/2","doc":"Makes each character in a string uppercase. It has no effect on strings\nwhich are already all uppercase.","ref":"Liquex.Filter.html#upcase/2"},{"type":"function","title":"Examples - Liquex.Filter.upcase/2","doc":"iex> Liquex.Filter.upcase(\"Parker Moore\", %{})\n    \"PARKER MOORE\"\n\n    iex> Liquex.Filter.upcase(\"APPLE\", %{})\n    \"APPLE\"","ref":"Liquex.Filter.html#upcase/2-examples"},{"type":"function","title":"Liquex.Filter.url_decode/2","doc":"Decodes a string that has been encoded as a URL or by url_encode/2.","ref":"Liquex.Filter.html#url_decode/2"},{"type":"function","title":"Examples - Liquex.Filter.url_decode/2","doc":"iex> Liquex.Filter.url_decode(\"%27Stop%21%27+said+Fred\", %{})\n    \"'Stop!' said Fred\"","ref":"Liquex.Filter.html#url_decode/2-examples"},{"type":"function","title":"Liquex.Filter.url_encode/2","doc":"Decodes a string that has been encoded as a URL or by url_encode/2.","ref":"Liquex.Filter.html#url_encode/2"},{"type":"function","title":"Examples - Liquex.Filter.url_encode/2","doc":"iex> Liquex.Filter.url_encode(\"john@liquid.com\", %{})\n    \"john%40liquid.com\"\n\n    iex> Liquex.Filter.url_encode(\"Tetsuro Takara\", %{})\n    \"Tetsuro+Takara\"","ref":"Liquex.Filter.html#url_encode/2-examples"},{"type":"function","title":"Liquex.Filter.where/3","doc":"Creates an array including only the objects with a given truthy property value","ref":"Liquex.Filter.html#where/3"},{"type":"function","title":"Examples - Liquex.Filter.where/3","doc":"iex> Liquex.Filter.where([%{\"b\" => true, \"value\" => 1}, %{\"b\" => 1, \"value\" => 2}, %{\"b\" => false, \"value\" => 3}], \"b\", %{})\n    [%{\"b\" => true, \"value\" => 1}, %{\"b\" => 1, \"value\" => 2}]","ref":"Liquex.Filter.html#where/3-examples"},{"type":"function","title":"Liquex.Filter.where/4","doc":"Creates an array including only the objects with a given property value, or\nany truthy value by default.","ref":"Liquex.Filter.html#where/4"},{"type":"function","title":"Examples - Liquex.Filter.where/4","doc":"iex> Liquex.Filter.where([%{\"b\" => 2}, %{\"b\" => 1}], \"b\", 1, %{})\n    [%{\"b\" => 1}]","ref":"Liquex.Filter.html#where/4-examples"},{"type":"type","title":"Liquex.Filter.filter_t/0","doc":"","ref":"Liquex.Filter.html#t:filter_t/0"},{"type":"module","title":"Liquex.LocalFileSystem","doc":"This implements an abstract file system which retrieves template files named\nin a manner similar to liquid, ie. with the template name prefixed with an\nunderscore. The extension \".liquid\" is also added.\n\nFor security reasons, template paths are only allowed to contain letters,\nnumbers, and underscore.\n\nExample:\n\n  iex> file_system = Liquex.LocalFileSystem.new(\"/some/path\")\n  iex> Liquex.LocalFileSystem.full_path(file_system, \"mypartial\")\n  \"/some/path/_mypartial.liquid\"\n\nOptionally in the second argument you can specify a custom pattern for template filenames.\n%s is replaced with the template name. Default pattern is \"_%s.liquid\".\n\nExample:\n\n  iex> file_system = Liquex.LocalFileSystem.new(\"/some/path\", \"%s.html\")\n  iex> Liquex.LocalFileSystem.full_path(file_system, \"mypartial\")\n  \"/some/path/mypartial.html\"","ref":"Liquex.LocalFileSystem.html"},{"type":"function","title":"Liquex.LocalFileSystem.full_path/2","doc":"","ref":"Liquex.LocalFileSystem.html#full_path/2"},{"type":"function","title":"Liquex.LocalFileSystem.new/2","doc":"","ref":"Liquex.LocalFileSystem.html#new/2"},{"type":"type","title":"Liquex.LocalFileSystem.t/0","doc":"","ref":"Liquex.LocalFileSystem.html#t:t/0"},{"type":"module","title":"Liquex.Parser","doc":"Liquid parser","ref":"Liquex.Parser.html"},{"type":"module","title":"Liquex.Parser.Field","doc":"Helper parsers for parsing fields","ref":"Liquex.Parser.Field.html"},{"type":"function","title":"Liquex.Parser.Field.field/1","doc":"Parses a field","ref":"Liquex.Parser.Field.html#field/1"},{"type":"function","title":"Examples - Liquex.Parser.Field.field/1","doc":"* \"my_variable\"\n    * \"my_variable.child_value\"\n    * \"my_variable[0]\"\n    * \"my_variable.child.value[3]\"","ref":"Liquex.Parser.Field.html#field/1-examples"},{"type":"function","title":"Liquex.Parser.Field.identifier/1","doc":"Parses an identifier\n\nIdentifiers can start with any letter or underscore.\n  * The remaining characters may include digits\n  * May end in a question mark (?)","ref":"Liquex.Parser.Field.html#identifier/1"},{"type":"function","title":"Examples - Liquex.Parser.Field.identifier/1","doc":"* \"my_variable\"\n    * \"is_valid?\"\n    * \"variable_1\"","ref":"Liquex.Parser.Field.html#identifier/1-examples"},{"type":"module","title":"Liquex.Parser.Literal","doc":"Helper parsers for parsing literal values in Liquid","ref":"Liquex.Parser.Literal.html"},{"type":"function","title":"Liquex.Parser.Literal.literal/1","doc":"Parses a literal","ref":"Liquex.Parser.Literal.html#literal/1"},{"type":"function","title":"Examples - Liquex.Parser.Literal.literal/1","doc":"* \"true\"\n    * \"false\"\n    * \"nil\"\n    * \"3.14\"\n    * \"3\"\n    * \"'Hello World!'\"\n    * \"\"Hello World!\"\"","ref":"Liquex.Parser.Literal.html#literal/1-examples"},{"type":"function","title":"Liquex.Parser.Literal.non_breaking_whitespace/2","doc":"Parses not line breaking white space, given a minimum.","ref":"Liquex.Parser.Literal.html#non_breaking_whitespace/2"},{"type":"function","title":"Examples - Liquex.Parser.Literal.non_breaking_whitespace/2","doc":"* \"  \"\n    * \"\t\"","ref":"Liquex.Parser.Literal.html#non_breaking_whitespace/2-examples"},{"type":"function","title":"Liquex.Parser.Literal.quoted_string/0","doc":"Parses a single or double quoted string.\n\nStrings may have escaped quotes within them.","ref":"Liquex.Parser.Literal.html#quoted_string/0"},{"type":"function","title":"Examples - Liquex.Parser.Literal.quoted_string/0","doc":"Examples here include the quotes as given, as opposed to other examples.\n\n    * \"Hello World\"\n    * 'Hello World'\n    * \"Hello \"World\"\"\n    * 'Hello \"World\"'\n    * 'Hello 'World''","ref":"Liquex.Parser.Literal.html#quoted_string/0-examples"},{"type":"function","title":"Liquex.Parser.Literal.range/1","doc":"Parses a range","ref":"Liquex.Parser.Literal.html#range/1"},{"type":"function","title":"Examples - Liquex.Parser.Literal.range/1","doc":"* \"(1..5)\"\n    * \"(1..num)\"","ref":"Liquex.Parser.Literal.html#range/1-examples"},{"type":"function","title":"Liquex.Parser.Literal.text/1","doc":"Parses everything outside of the Liquid tags. We call this text but it's any\nunstructed data not specifically parsed by Liquex.","ref":"Liquex.Parser.Literal.html#text/1"},{"type":"function","title":"Liquex.Parser.Literal.whitespace/2","doc":"Parses white space, given a minimum.","ref":"Liquex.Parser.Literal.html#whitespace/2"},{"type":"function","title":"Examples - Liquex.Parser.Literal.whitespace/2","doc":"* \"  \"\n    * \"\r\n\t\"","ref":"Liquex.Parser.Literal.html#whitespace/2-examples"},{"type":"module","title":"Liquex.Parser.Object","doc":"Helper methods for parsing object tags and arguments used by objects","ref":"Liquex.Parser.Object.html"},{"type":"function","title":"Liquex.Parser.Object.arguments/1","doc":"Parse arguments. Arguments are key/value pairs, but a key may have multiple\nvalues separated by commas.","ref":"Liquex.Parser.Object.html#arguments/1"},{"type":"function","title":"Examples - Liquex.Parser.Object.arguments/1","doc":"* \"img_url: '400x400', crop: 'bottom', filter: 'blur'\"\n    * \"img_size: 800, 600\"","ref":"Liquex.Parser.Object.html#arguments/1-examples"},{"type":"function","title":"Liquex.Parser.Object.close_object_remove_whitespace/1","doc":"Parses closing object tag with white space removing.","ref":"Liquex.Parser.Object.html#close_object_remove_whitespace/1"},{"type":"function","title":"Examples - Liquex.Parser.Object.close_object_remove_whitespace/1","doc":"* \"-}}  \"","ref":"Liquex.Parser.Object.html#close_object_remove_whitespace/1-examples"},{"type":"function","title":"Liquex.Parser.Object.filter/1","doc":"Parses filter that starts with a pipe","ref":"Liquex.Parser.Object.html#filter/1"},{"type":"function","title":"Examples - Liquex.Parser.Object.filter/1","doc":"* \"| sort\"\n    * \"| at_most: 5\"","ref":"Liquex.Parser.Object.html#filter/1-examples"},{"type":"function","title":"Liquex.Parser.Object.keyword_field/1","doc":"Parse keyword field","ref":"Liquex.Parser.Object.html#keyword_field/1"},{"type":"function","title":"Examples - Liquex.Parser.Object.keyword_field/1","doc":"* \"key: value\"","ref":"Liquex.Parser.Object.html#keyword_field/1-examples"},{"type":"function","title":"Liquex.Parser.Object.keyword_fields/1","doc":"","ref":"Liquex.Parser.Object.html#keyword_fields/1"},{"type":"function","title":"Liquex.Parser.Object.object/1","doc":"Parses object. May contain arguments, literals, and filters.\n\nIt special cases space removing tags such as `{{-` and `-}}` to properly\nremove any spaces leading and trailing spaces if requested.","ref":"Liquex.Parser.Object.html#object/1"},{"type":"function","title":"Examples - Liquex.Parser.Object.object/1","doc":"* \"{{ 'hello world' }}\"\n    * \"{{ 5 + 5 }}\"\n    * \"{{ variable_a | at_most: 5 }}\"\n    * \"{{- my_array | sort -}}\"","ref":"Liquex.Parser.Object.html#object/1-examples"},{"type":"module","title":"Liquex.Parser.Tag","doc":"Helper methods for parsing tags","ref":"Liquex.Parser.Tag.html"},{"type":"function","title":"Liquex.Parser.Tag.close_tag/1","doc":"Parse close tags","ref":"Liquex.Parser.Tag.html#close_tag/1"},{"type":"function","title":"Examples - Liquex.Parser.Tag.close_tag/1","doc":"* \"%}\"\n    * \"-%} \"","ref":"Liquex.Parser.Tag.html#close_tag/1-examples"},{"type":"function","title":"Liquex.Parser.Tag.end_liquid_line/1","doc":"Read to end of a line within a liquid tag. Reads to end of line (\"\\r\" and/or\n\"\\n\") or to a closing tag \"%}\".","ref":"Liquex.Parser.Tag.html#end_liquid_line/1"},{"type":"function","title":"Liquex.Parser.Tag.expression_tag/2","doc":"Parse tag with no expression","ref":"Liquex.Parser.Tag.html#expression_tag/2"},{"type":"function","title":"Examples - Liquex.Parser.Tag.expression_tag/2","doc":"* \"{% if a == 5 %}\"\n    * \"{% elsif b >= 10 and a < 4 %}\"","ref":"Liquex.Parser.Tag.html#expression_tag/2-examples"},{"type":"function","title":"Liquex.Parser.Tag.liquid_tag_directive/2","doc":"","ref":"Liquex.Parser.Tag.html#liquid_tag_directive/2"},{"type":"function","title":"Liquex.Parser.Tag.liquid_tag_expression/2","doc":"","ref":"Liquex.Parser.Tag.html#liquid_tag_expression/2"},{"type":"function","title":"Liquex.Parser.Tag.open_tag/1","doc":"Parse open tags","ref":"Liquex.Parser.Tag.html#open_tag/1"},{"type":"function","title":"Examples - Liquex.Parser.Tag.open_tag/1","doc":"* \"{%\"\n    * \"{%-\"","ref":"Liquex.Parser.Tag.html#open_tag/1-examples"},{"type":"function","title":"Liquex.Parser.Tag.tag_directive/2","doc":"Parse basic tag with no arguments","ref":"Liquex.Parser.Tag.html#tag_directive/2"},{"type":"function","title":"Examples - Liquex.Parser.Tag.tag_directive/2","doc":"* \"{% break %}\"\n    * \"{% endfor %}\"","ref":"Liquex.Parser.Tag.html#tag_directive/2-examples"},{"type":"module","title":"Liquex.Represent","doc":"Helper methods for maps","ref":"Liquex.Represent.html"},{"type":"function","title":"Liquex.Represent.expand/1","doc":"Expands a previously represented object.\n\nUseful when the represented object contains lazy fields. This can be useful\nfor generating JSON values from a represented object. For example, if you\nhad a `dump` filter that dumped a value to the page as JSON, you would use\nthis function so that lazy functions get represented correctly instead of\nas functions.","ref":"Liquex.Represent.html#expand/1"},{"type":"function","title":"Liquex.Represent.represent/2","doc":"Convert any object and deeply maps atom keys to strings\n\nThe value `deep` determines if it should eagerly represent the object. If\nset to false, it will return a function for any nested objects.\n\nLazy values are automatically evaluated in the Liquid rendering engine.","ref":"Liquex.Represent.html#represent/2"},{"type":"protocol","title":"Liquex.Representable","doc":"","ref":"Liquex.Representable.html"},{"type":"function","title":"Liquex.Representable.is_lazy/1","doc":"","ref":"Liquex.Representable.html#is_lazy/1"},{"type":"function","title":"Liquex.Representable.represent/2","doc":"","ref":"Liquex.Representable.html#represent/2"},{"type":"type","title":"Liquex.Representable.t/0","doc":"All the types that implement this protocol.","ref":"Liquex.Representable.html#t:t/0"},{"type":"behaviour","title":"Liquex.Tag","doc":"Behaviour for building a tag parser and renderer in Liquex.\n\nTo build a custom tag, create a new module and implement the `Liquex.Tag` behaviour.\n\n    defmodule CustomTag do\n      @behaviour Liquex.Tag\n\n      import NimbleParsec\n\n      @impl true\n      # Parse < >\n      def parse() do\n        text =\n          lookahead_not(string(\">>\"))\n          |> utf8_char([])\n          |> times(min: 1)\n          |> reduce({Kernel, :to_string, []})\n          |> tag(:text)\n\n        combinator\n        |> ignore(string(\"<<\"))\n        |> optional(text)\n        |> ignore(string(\">>\"))\n      end\n\n      @impl true\n      def render(contents, context) do\n        {result, context} = Liquex.Render.render!(contents, context)\n        {[\"Custom Tag: \", result], context}\n      end\n    end\n\nYou will then have to create a new parser to parse any custom tags.\n\n    defmodule CustomParser do\n      use Liquex.Parser, tags: [CustomTag, OtherTag]\n    end\n\nFrom there, you can parse and render your liquid content.\n\n    {:ok, document} = Liquex.parse(\"< >\", CustomParser)\n    {result, _} = Liquex.render!(document, context)","ref":"Liquex.Tag.html"},{"type":"callback","title":"Liquex.Tag.parse/0","doc":"Returns a `NimbleParsec` expression to parse a tag.","ref":"Liquex.Tag.html#c:parse/0"},{"type":"callback","title":"Liquex.Tag.parse_liquid_tag/0","doc":"Returns a `NimbleParsec` expression to parse a tag within a liquid expression\ntag.\n\n#","ref":"Liquex.Tag.html#c:parse_liquid_tag/0"},{"type":"callback","title":"Example - Liquex.Tag.parse_liquid_tag/0","doc":"{% liquid echo \"Hello World!\" %}","ref":"Liquex.Tag.html#c:parse_liquid_tag/0-example"},{"type":"callback","title":"Liquex.Tag.render/2","doc":"Render the tag built by the parser defined in `parse/0`","ref":"Liquex.Tag.html#c:render/2"},{"type":"module","title":"Liquex.Tag.AssignTag","doc":"Creates a new named variable.\n\n#","ref":"Liquex.Tag.AssignTag.html"},{"type":"module","title":"Input - Liquex.Tag.AssignTag","doc":"{% assign my_variable = false %}\n    {% if my_variable != true %}\n      This statement is valid.\n    {% endif %}\n\n#","ref":"Liquex.Tag.AssignTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.AssignTag","doc":"This statement is valid.\n\nWrap a value in quotations \" to save it as a string variable.\n\n#","ref":"Liquex.Tag.AssignTag.html#module-output"},{"type":"module","title":"Input - Liquex.Tag.AssignTag","doc":"{% assign foo = \"bar\" %}\n    {{ foo }}\n\n#","ref":"Liquex.Tag.AssignTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.AssignTag","doc":"bar","ref":"Liquex.Tag.AssignTag.html#module-output"},{"type":"function","title":"Liquex.Tag.AssignTag.assign_contents/1","doc":"","ref":"Liquex.Tag.AssignTag.html#assign_contents/1"},{"type":"function","title":"Liquex.Tag.AssignTag.parse/0","doc":"","ref":"Liquex.Tag.AssignTag.html#parse/0"},{"type":"function","title":"Liquex.Tag.AssignTag.parse_liquid_tag/0","doc":"","ref":"Liquex.Tag.AssignTag.html#parse_liquid_tag/0"},{"type":"function","title":"Liquex.Tag.AssignTag.render/2","doc":"","ref":"Liquex.Tag.AssignTag.html#render/2"},{"type":"module","title":"Liquex.Tag.BreakTag","doc":"Causes the loop to stop iterating when it encounters the break tag.\n\n#","ref":"Liquex.Tag.BreakTag.html"},{"type":"module","title":"Input - Liquex.Tag.BreakTag","doc":"{% for i in (1..5) %}\n      {% if i == 4 %}\n        {% break %}\n      {% else %}\n        {{ i }}\n      {% endif %}\n    {% endfor %}\n\n#","ref":"Liquex.Tag.BreakTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.BreakTag","doc":"1 2 3","ref":"Liquex.Tag.BreakTag.html#module-output"},{"type":"module","title":"Liquex.Tag.CaptureTag","doc":"Captures the string inside of the opening and closing tags and assigns it to a\nvariable. Variables created using capture are stored as strings.\n\n#","ref":"Liquex.Tag.CaptureTag.html"},{"type":"module","title":"Input - Liquex.Tag.CaptureTag","doc":"{% capture my_variable %}I am being captured.{% endcapture %}\n    {{ my_variable }}\n\n#","ref":"Liquex.Tag.CaptureTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.CaptureTag","doc":"I am being captured.\n\nUsing capture, you can create complex strings using other variables created\nwith assign.\n\n#","ref":"Liquex.Tag.CaptureTag.html#module-output"},{"type":"module","title":"Input - Liquex.Tag.CaptureTag","doc":"{% assign favorite_food = \"pizza\" %}\n    {% assign age = 35 %}\n\n    {% capture about_me %}\n    I am {{ age }} and my favorite food is {{ favorite_food }}.\n    {% endcapture %}\n\n    {{ about_me }}\n\n#","ref":"Liquex.Tag.CaptureTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.CaptureTag","doc":"I am 35 and my favourite food is pizza.","ref":"Liquex.Tag.CaptureTag.html#module-output"},{"type":"function","title":"Liquex.Tag.CaptureTag.parse/0","doc":"","ref":"Liquex.Tag.CaptureTag.html#parse/0"},{"type":"function","title":"Liquex.Tag.CaptureTag.render/2","doc":"","ref":"Liquex.Tag.CaptureTag.html#render/2"},{"type":"module","title":"Liquex.Tag.CaseTag","doc":"Creates a switch statement to execute a particular block of code when a\nvariable has a specified value. case initializes the switch statement, and\nwhen statements define the various conditions.\n\nAn optional else statement at the end of the case provides code to execute if\nnone of the conditions are met.\n\n#","ref":"Liquex.Tag.CaseTag.html"},{"type":"module","title":"Input - Liquex.Tag.CaseTag","doc":"{% assign handle = \"cake\" %}\n    {% case handle %}\n      {% when \"cake\" %}\n        This is a cake\n      {% when \"cookie\", \"biscuit\" %}\n        This is a cookie\n      {% else %}\n        This is not a cake nor a cookie\n    {% endcase %}\n\n#","ref":"Liquex.Tag.CaseTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.CaseTag","doc":"This is a cake","ref":"Liquex.Tag.CaseTag.html#module-output"},{"type":"function","title":"Liquex.Tag.CaseTag.else_tag/0","doc":"","ref":"Liquex.Tag.CaseTag.html#else_tag/0"},{"type":"function","title":"Liquex.Tag.CaseTag.parse/0","doc":"","ref":"Liquex.Tag.CaseTag.html#parse/0"},{"type":"function","title":"Liquex.Tag.CaseTag.parse_liquid_tag/0","doc":"","ref":"Liquex.Tag.CaseTag.html#parse_liquid_tag/0"},{"type":"function","title":"Liquex.Tag.CaseTag.render/2","doc":"","ref":"Liquex.Tag.CaseTag.html#render/2"},{"type":"module","title":"Liquex.Tag.CommentTag","doc":"Allows you to leave un-rendered code inside a Liquid template. Any text within\nthe opening and closing comment blocks will not be printed, and any Liquid\ncode within will not be executed.\n\n#","ref":"Liquex.Tag.CommentTag.html"},{"type":"module","title":"Input - Liquex.Tag.CommentTag","doc":"{% assign verb = \"turned\" %}\n    {% comment %}\n    {% assign verb = \"converted\" %}\n    {% endcomment %}\n    Anything you put between {% comment %} and {% endcomment %} tags\n    is {{ verb }} into a comment.\n\n#","ref":"Liquex.Tag.CommentTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.CommentTag","doc":"Anything you put between  tags\n    is turned into a comment.","ref":"Liquex.Tag.CommentTag.html#module-output"},{"type":"module","title":"Liquex.Tag.ContinueTag","doc":"Causes the loop to skip the current iteration when it encounters the continue\ntag.\n\n#","ref":"Liquex.Tag.ContinueTag.html"},{"type":"module","title":"Input - Liquex.Tag.ContinueTag","doc":"{% for i in (1..5) %}\n      {% if i == 4 %}\n        {% continue %}\n      {% else %}\n        {{ i }}\n      {% endif %}\n    {% endfor %}\n\n#","ref":"Liquex.Tag.ContinueTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.ContinueTag","doc":"1 2 3   5","ref":"Liquex.Tag.ContinueTag.html#module-output"},{"type":"module","title":"Liquex.Tag.CycleTag","doc":"Loops through a group of strings and prints them in the order that they were\npassed as arguments. Each time cycle is called, the next string argument is\nprinted.\n\ncycle must be used within a for loop block.\n\n#","ref":"Liquex.Tag.CycleTag.html"},{"type":"module","title":"Input - Liquex.Tag.CycleTag","doc":"{% cycle \"one\", \"two\", \"three\" %}\n    {% cycle \"one\", \"two\", \"three\" %}\n    {% cycle \"one\", \"two\", \"three\" %}\n    {% cycle \"one\", \"two\", \"three\" %}\n\n#","ref":"Liquex.Tag.CycleTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.CycleTag","doc":"one\n    two\n    three\n    one\n\nUses for cycle include:\n\n  * applying odd/even classes to rows in a table\n  * applying a unique class to the last product thumbnail in a row","ref":"Liquex.Tag.CycleTag.html#module-output"},{"type":"module","title":"cycle (parameters) - Liquex.Tag.CycleTag","doc":"cycle accepts a “cycle group” parameter in cases where you need multiple cycle\nblocks in one template. If no name is supplied for the cycle group, then it is\nassumed that multiple calls with the same parameters are one group.\n\n#","ref":"Liquex.Tag.CycleTag.html#module-cycle-parameters"},{"type":"module","title":"Input - Liquex.Tag.CycleTag","doc":"{% cycle \"first\": \"one\", \"two\", \"three\" %}\n    {% cycle \"second\": \"one\", \"two\", \"three\" %}\n    {% cycle \"second\": \"one\", \"two\", \"three\" %}\n    {% cycle \"first\": \"one\", \"two\", \"three\" %}\n\n#","ref":"Liquex.Tag.CycleTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.CycleTag","doc":"one\n    one\n    two\n    two","ref":"Liquex.Tag.CycleTag.html#module-output"},{"type":"function","title":"Liquex.Tag.CycleTag.do_parse_cycle/1","doc":"","ref":"Liquex.Tag.CycleTag.html#do_parse_cycle/1"},{"type":"function","title":"Liquex.Tag.CycleTag.parse/0","doc":"","ref":"Liquex.Tag.CycleTag.html#parse/0"},{"type":"function","title":"Liquex.Tag.CycleTag.parse_liquid_tag/0","doc":"","ref":"Liquex.Tag.CycleTag.html#parse_liquid_tag/0"},{"type":"function","title":"Liquex.Tag.CycleTag.render/2","doc":"","ref":"Liquex.Tag.CycleTag.html#render/2"},{"type":"module","title":"Liquex.Tag.EchoTag","doc":"Outputs an expression in the rendered HTML. This is identical to wrapping an\nexpression in {{ and }}, but works inside liquid tags and supports filters.\n\n#","ref":"Liquex.Tag.EchoTag.html"},{"type":"module","title":"Input - Liquex.Tag.EchoTag","doc":"{% liquid\n    for product in collection.products\n      echo product.title | capitalize\n    endfor %}\n\n#","ref":"Liquex.Tag.EchoTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.EchoTag","doc":"Hat Shirt Pants","ref":"Liquex.Tag.EchoTag.html#module-output"},{"type":"module","title":"Liquex.Tag.ForTag","doc":"Repeatedly executes a block of code. For a full list of attributes available\nwithin a for loop, see forloop (object).\n\n#","ref":"Liquex.Tag.ForTag.html"},{"type":"module","title":"Input - Liquex.Tag.ForTag","doc":"{% for product in collection.products %}\n      {{ product.title }}\n    {% endfor %}\n\n#","ref":"Liquex.Tag.ForTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.ForTag","doc":"hat shirt pants","ref":"Liquex.Tag.ForTag.html#module-output"},{"type":"module","title":"else - Liquex.Tag.ForTag","doc":"Specifies a fallback case for a for loop which will run if the loop has zero length.\n\n#","ref":"Liquex.Tag.ForTag.html#module-else"},{"type":"module","title":"Input - Liquex.Tag.ForTag","doc":"{% for product in collection.products %}\n      {{ product.title }}\n    {% else %}\n      The collection is empty.\n    {% endfor %}\n\n#","ref":"Liquex.Tag.ForTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.ForTag","doc":"The collection is empty.","ref":"Liquex.Tag.ForTag.html#module-output"},{"type":"module","title":"break - Liquex.Tag.ForTag","doc":"Causes the loop to stop iterating when it encounters the break tag.\n\n#","ref":"Liquex.Tag.ForTag.html#module-break"},{"type":"module","title":"Input - Liquex.Tag.ForTag","doc":"{% for i in (1..5) %}\n      {% if i == 4 %}\n        {% break %}\n      {% else %}\n        {{ i }}\n      {% endif %}\n    {% endfor %}\n\n#","ref":"Liquex.Tag.ForTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.ForTag","doc":"1 2 3","ref":"Liquex.Tag.ForTag.html#module-output"},{"type":"module","title":"continue - Liquex.Tag.ForTag","doc":"Causes the loop to skip the current iteration when it encounters the continue\ntag.\n\n#","ref":"Liquex.Tag.ForTag.html#module-continue"},{"type":"module","title":"Input - Liquex.Tag.ForTag","doc":"{% for i in (1..5) %}\n      {% if i == 4 %}\n        {% continue %}\n      {% else %}\n        {{ i }}\n      {% endif %}\n    {% endfor %}\n\n#","ref":"Liquex.Tag.ForTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.ForTag","doc":"1 2 3   5\n\n# for (parameters)","ref":"Liquex.Tag.ForTag.html#module-output"},{"type":"module","title":"limit - Liquex.Tag.ForTag","doc":"Limits the loop to the specified number of iterations.\n\n#","ref":"Liquex.Tag.ForTag.html#module-limit"},{"type":"module","title":"Input - Liquex.Tag.ForTag","doc":"<!-- if array = [1,2,3,4,5,6] -->\n    {% for item in array limit:2 %}\n      {{ item }}\n    {% endfor %}\n\n#","ref":"Liquex.Tag.ForTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.ForTag","doc":"1 2","ref":"Liquex.Tag.ForTag.html#module-output"},{"type":"module","title":"offset - Liquex.Tag.ForTag","doc":"Begins the loop at the specified index.\n\n#","ref":"Liquex.Tag.ForTag.html#module-offset"},{"type":"module","title":"Input - Liquex.Tag.ForTag","doc":"<!-- if array = [1,2,3,4,5,6] -->\n    {% for item in array offset:2 %}\n      {{ item }}\n    {% endfor %}\n\n#","ref":"Liquex.Tag.ForTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.ForTag","doc":"3 4 5 6\n\nTo start a loop from where the last loop using the same iterator left off,\npass the special word continue.\n\n#","ref":"Liquex.Tag.ForTag.html#module-output"},{"type":"module","title":"Input - Liquex.Tag.ForTag","doc":"<!-- if array = [1,2,3,4,5,6] -->\n    {% for item in array limit: 3 %}\n      {{ item }}\n    {% endfor %}\n    {% for item in array limit: 3 offset: continue %}\n      {{ item }}\n    {% endfor %}\n\n#","ref":"Liquex.Tag.ForTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.ForTag","doc":"1 2 3\n    4 5 6","ref":"Liquex.Tag.ForTag.html#module-output"},{"type":"module","title":"range - Liquex.Tag.ForTag","doc":"Defines a range of numbers to loop through. The range can be defined by both\nliteral and variable numbers, and can be pulled from a variable.\n\n#","ref":"Liquex.Tag.ForTag.html#module-range"},{"type":"module","title":"Input - Liquex.Tag.ForTag","doc":"{% for i in (3..5) %}\n      {{ i }}\n    {% endfor %}\n\n    {% assign num = 4 %}\n    {% assign range = (1..num) %}\n    {% for i in range %}\n      {{ i }}\n    {% endfor %}\n\n#","ref":"Liquex.Tag.ForTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.ForTag","doc":"3 4 5\n    1 2 3 4","ref":"Liquex.Tag.ForTag.html#module-output"},{"type":"module","title":"reversed - Liquex.Tag.ForTag","doc":"Reverses the order of the loop. Note that this flag’s spelling is different\nfrom the filter reverse.\n\n#","ref":"Liquex.Tag.ForTag.html#module-reversed"},{"type":"module","title":"Input - Liquex.Tag.ForTag","doc":"<!-- if array = [1,2,3,4,5,6] -->\n    {% for item in array reversed %}\n      {{ item }}\n    {% endfor %}\n\n#","ref":"Liquex.Tag.ForTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.ForTag","doc":"6 5 4 3 2 1","ref":"Liquex.Tag.ForTag.html#module-output"},{"type":"function","title":"Liquex.Tag.ForTag.parse/0","doc":"","ref":"Liquex.Tag.ForTag.html#parse/0"},{"type":"function","title":"Liquex.Tag.ForTag.parse_liquid_tag/0","doc":"","ref":"Liquex.Tag.ForTag.html#parse_liquid_tag/0"},{"type":"function","title":"Liquex.Tag.ForTag.render/2","doc":"","ref":"Liquex.Tag.ForTag.html#render/2"},{"type":"function","title":"Liquex.Tag.ForTag.render_collection/5","doc":"","ref":"Liquex.Tag.ForTag.html#render_collection/5"},{"type":"module","title":"Liquex.Tag.IfTag","doc":"Executes a block of code only if a certain condition is true.\n\n#","ref":"Liquex.Tag.IfTag.html"},{"type":"module","title":"Input - Liquex.Tag.IfTag","doc":"{% if product.title == \"Awesome Shoes\" %}\n      These shoes are awesome!\n    {% endif %}\n\n#","ref":"Liquex.Tag.IfTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.IfTag","doc":"These shoes are awesome!","ref":"Liquex.Tag.IfTag.html#module-output"},{"type":"function","title":"Liquex.Tag.IfTag.else_tag/0","doc":"","ref":"Liquex.Tag.IfTag.html#else_tag/0"},{"type":"function","title":"Liquex.Tag.IfTag.elsif_tag/0","doc":"","ref":"Liquex.Tag.IfTag.html#elsif_tag/0"},{"type":"module","title":"Liquex.Tag.IncrementTag","doc":"","ref":"Liquex.Tag.IncrementTag.html"},{"type":"module","title":"increment - Liquex.Tag.IncrementTag","doc":"Creates and outputs a new number variable with initial value 0. On subsequent\ncalls, it increases its value by one and outputs the new value.\n\n#","ref":"Liquex.Tag.IncrementTag.html#module-increment"},{"type":"module","title":"Input - Liquex.Tag.IncrementTag","doc":"{% increment my_counter %}\n    {% increment my_counter %}\n    {% increment my_counter %}\n\n#","ref":"Liquex.Tag.IncrementTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.IncrementTag","doc":"0\n  1\n  2\n\nVariables created using increment are independent from variables created using\nassign or capture.\n\nIn the example below, a variable named “var” is created using assign. The\nincrement tag is then used several times on a variable with the same name.\nNote that the increment tag does not affect the value of “var” that was\ncreated using assign.\n\n#","ref":"Liquex.Tag.IncrementTag.html#module-output"},{"type":"module","title":"Input - Liquex.Tag.IncrementTag","doc":"{% assign var = 10 %}\n    {% increment var %}\n    {% increment var %}\n    {% increment var %}\n    {{ var }}\n\n#","ref":"Liquex.Tag.IncrementTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.IncrementTag","doc":"0\n    1\n    2\n    10","ref":"Liquex.Tag.IncrementTag.html#module-output"},{"type":"module","title":"decrement - Liquex.Tag.IncrementTag","doc":"Creates and outputs a new number variable with initial value -1. On subsequent\ncalls, it decreases its value by one and outputs the new value.\n\n#","ref":"Liquex.Tag.IncrementTag.html#module-decrement"},{"type":"module","title":"Input - Liquex.Tag.IncrementTag","doc":"{% decrement variable %}\n    {% decrement variable %}\n    {% decrement variable %}\n\n#","ref":"Liquex.Tag.IncrementTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.IncrementTag","doc":"-1\n    -2\n    -3\n\nLike increment, variables declared using decrement are independent from\nvariables created using assign or capture.","ref":"Liquex.Tag.IncrementTag.html#module-output"},{"type":"function","title":"Liquex.Tag.IncrementTag.parse/0","doc":"","ref":"Liquex.Tag.IncrementTag.html#parse/0"},{"type":"function","title":"Liquex.Tag.IncrementTag.parse_liquid_tag/0","doc":"","ref":"Liquex.Tag.IncrementTag.html#parse_liquid_tag/0"},{"type":"function","title":"Liquex.Tag.IncrementTag.render/2","doc":"","ref":"Liquex.Tag.IncrementTag.html#render/2"},{"type":"function","title":"Liquex.Tag.IncrementTag.reverse_tags/5","doc":"","ref":"Liquex.Tag.IncrementTag.html#reverse_tags/5"},{"type":"module","title":"Liquex.Tag.InlineCommentTag","doc":"A tag that allows for inline comments using the # character.","ref":"Liquex.Tag.InlineCommentTag.html"},{"type":"module","title":"liquid - Liquex.Tag.InlineCommentTag","doc":"Nothing in the comments will be rendered.\n    {% # This is a comment and won't be rendered %}\n\n    {% liquid # This is also a comment and won't be rendered %}\n\n\n#","ref":"Liquex.Tag.InlineCommentTag.html#module-liquid"},{"type":"module","title":"Output - Liquex.Tag.InlineCommentTag","doc":"Nothing in the comments will be rendered.","ref":"Liquex.Tag.InlineCommentTag.html#module-output"},{"type":"module","title":"Liquex.Tag.LiquidTag","doc":"","ref":"Liquex.Tag.LiquidTag.html"},{"type":"module","title":"liquid - Liquex.Tag.LiquidTag","doc":"Encloses multiple tags within one set of delimiters, to allow writing Liquid\nlogic more concisely.\n\n    {% liquid\n    case section.blocks.size\n    when 1\n      assign column_size = ''\n    when 2\n      assign column_size = 'one-half'\n    when 3\n      assign column_size = 'one-third'\n    else\n      assign column_size = 'one-quarter'\n    endcase %}\n\nBecause any tag blocks opened within a liquid tag must also be closed within\nthe same tag, use echo to output data.","ref":"Liquex.Tag.LiquidTag.html#module-liquid"},{"type":"module","title":"Liquex.Tag.ObjectTag","doc":"Objects contain the content that Liquid displays on a page. Objects and\nvariables are displayed when enclosed in double curly braces: {{ and }}.\n\n#","ref":"Liquex.Tag.ObjectTag.html"},{"type":"module","title":"Input - Liquex.Tag.ObjectTag","doc":"{{ page.title }}\n\n#","ref":"Liquex.Tag.ObjectTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.ObjectTag","doc":"Introduction\n\nIn this case, Liquid is rendering the content of the title property of the\npage object, which contains the text Introduction.","ref":"Liquex.Tag.ObjectTag.html#module-output"},{"type":"function","title":"Liquex.Tag.ObjectTag.close_object_remove_whitespace/0","doc":"","ref":"Liquex.Tag.ObjectTag.html#close_object_remove_whitespace/0"},{"type":"function","title":"Liquex.Tag.ObjectTag.filter/0","doc":"","ref":"Liquex.Tag.ObjectTag.html#filter/0"},{"type":"function","title":"Liquex.Tag.ObjectTag.filters/1","doc":"","ref":"Liquex.Tag.ObjectTag.html#filters/1"},{"type":"function","title":"Liquex.Tag.ObjectTag.parse/0","doc":"","ref":"Liquex.Tag.ObjectTag.html#parse/0"},{"type":"function","title":"Liquex.Tag.ObjectTag.render/2","doc":"","ref":"Liquex.Tag.ObjectTag.html#render/2"},{"type":"module","title":"Liquex.Tag.RawTag","doc":"Temporarily disables tag processing. This is useful for generating certain\ncontent that uses conflicting syntax, such as Mustache or Handlebars.\n\n#","ref":"Liquex.Tag.RawTag.html"},{"type":"module","title":"Input - Liquex.Tag.RawTag","doc":"{% raw %}\n    In Handlebars, {{ this }} will be HTML-escaped, but {{{ that }}} will not.\n    {% endraw %}\n\n#","ref":"Liquex.Tag.RawTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.RawTag","doc":"In Handlebars, {{ this }} will be HTML-escaped, but {{{ that }}} will not.","ref":"Liquex.Tag.RawTag.html#module-output"},{"type":"function","title":"Liquex.Tag.RawTag.parse/0","doc":"","ref":"Liquex.Tag.RawTag.html#parse/0"},{"type":"function","title":"Liquex.Tag.RawTag.render/2","doc":"","ref":"Liquex.Tag.RawTag.html#render/2"},{"type":"module","title":"Liquex.Tag.RenderTag","doc":"Insert the rendered content of another template within the current template.\n\n    {% render \"template-name\" %}\n\nNote that you don’t need to write the file’s .liquid extension.\n\nThe code within the rendered template does not automatically have access to\nthe variables assigned using variable tags within the parent template.\nSimilarly, variables assigned within the rendered template cannot be accessed\nby code in any other template.","ref":"Liquex.Tag.RenderTag.html"},{"type":"module","title":"render (parameters) - Liquex.Tag.RenderTag","doc":"Variables assigned using variable tags can be passed to a template by listing\nthem as parameters on the render tag.\n\n    {% assign my_variable = \"apples\" %}\n    {% render \"name\", my_variable: my_variable, my_other_variable: \"oranges\" %}\n\nOne or more objects can be passed to a template.\n\n    {% assign featured_product = all_products[\"product_handle\"] %}\n    {% render \"product\", product: featured_product %}","ref":"Liquex.Tag.RenderTag.html#module-render-parameters"},{"type":"module","title":"with - Liquex.Tag.RenderTag","doc":"A single object can be passed to a template by using the with and optional as\nparameters.\n\n    {% assign featured_product = all_products[\"product_handle\"] %}\n    {% render \"product\" with featured_product as product %}\n\nIn the example above, the product variable in the rendered template will hold\nthe value of featured_product from the parent template.","ref":"Liquex.Tag.RenderTag.html#module-with"},{"type":"module","title":"for - Liquex.Tag.RenderTag","doc":"A template can be rendered once for each value of an enumerable object by\nusing the for and optional as parameters.\n\n    {% assign variants = product.variants %}\n    {% render \"product_variant\" for variants as variant %}\n\nIn the example above, the template will be rendered once for each variant of\nthe product, and the variant variable will hold a different product variant\nobject for each iteration.\n\nWhen using the for parameter, the forloop object is accessible within the\nrendered template.","ref":"Liquex.Tag.RenderTag.html#module-for"},{"type":"function","title":"Liquex.Tag.RenderTag.parse/0","doc":"","ref":"Liquex.Tag.RenderTag.html#parse/0"},{"type":"function","title":"Liquex.Tag.RenderTag.parse_liquid_tag/0","doc":"","ref":"Liquex.Tag.RenderTag.html#parse_liquid_tag/0"},{"type":"function","title":"Liquex.Tag.RenderTag.render/2","doc":"","ref":"Liquex.Tag.RenderTag.html#render/2"},{"type":"module","title":"Liquex.Tag.TablerowTag","doc":"Generates an HTML table. Must be wrapped in opening   and closing\n  HTML tags. For a full list of attributes available within a tablerow\nloop, see tablerow (object).\n\n#","ref":"Liquex.Tag.TablerowTag.html"},{"type":"module","title":"Input - Liquex.Tag.TablerowTag","doc":"{% tablerow product in collection.products %}\n      {{ product.title }}\n    {% endtablerow %}\n     \n\n#","ref":"Liquex.Tag.TablerowTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.TablerowTag","doc":"Cool Shirt\n         \n         \n          Alien Poster\n         \n         \n          Batman Poster\n         \n         \n          Bullseye Shirt\n         \n         \n          Another Classic Vinyl\n         \n         \n          Awesome Jeans\n         \n       \n     \n\n# tablerow (parameters)","ref":"Liquex.Tag.TablerowTag.html#module-output"},{"type":"module","title":"cols - Liquex.Tag.TablerowTag","doc":"Defines how many columns the tables should have.\n\n#","ref":"Liquex.Tag.TablerowTag.html#module-cols"},{"type":"module","title":"Input - Liquex.Tag.TablerowTag","doc":"{% tablerow product in collection.products cols:2 %}\n      {{ product.title }}\n    {% endtablerow %}\n\n#","ref":"Liquex.Tag.TablerowTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.TablerowTag","doc":"Cool Shirt\n         \n         \n          Alien Poster\n         \n       \n       \n         \n          Batman Poster\n         \n         \n          Bullseye Shirt\n         \n       \n       \n         \n          Another Classic Vinyl\n         \n         \n          Awesome Jeans","ref":"Liquex.Tag.TablerowTag.html#module-output"},{"type":"module","title":"limit - Liquex.Tag.TablerowTag","doc":"Exits the tablerow loop after a specific index.\n\n    {% tablerow product in collection.products cols:2 limit:3 %}\n      {{ product.title }}\n    {% endtablerow %}","ref":"Liquex.Tag.TablerowTag.html#module-limit"},{"type":"module","title":"offset - Liquex.Tag.TablerowTag","doc":"Starts the tablerow loop after a specific index.\n\n    {% tablerow product in collection.products cols:2 offset:3 %}\n      {{ product.title }}\n    {% endtablerow %}","ref":"Liquex.Tag.TablerowTag.html#module-offset"},{"type":"module","title":"range - Liquex.Tag.TablerowTag","doc":"Defines a range of numbers to loop through. The range can be defined by both\nliteral and variable numbers.\n\n    <!--variable number example-->\n\n    {% assign num = 4 %}\n     \n    {% tablerow i in (1..num) %}\n      {{ i }}\n    {% endtablerow %}\n     \n\n    <!--literal number example-->\n\n     \n    {% tablerow i in (3..5) %}\n      {{ i }}\n    {% endtablerow %}","ref":"Liquex.Tag.TablerowTag.html#module-range"},{"type":"function","title":"Liquex.Tag.TablerowTag.parse/0","doc":"","ref":"Liquex.Tag.TablerowTag.html#parse/0"},{"type":"function","title":"Liquex.Tag.TablerowTag.parse_liquid_tag/0","doc":"","ref":"Liquex.Tag.TablerowTag.html#parse_liquid_tag/0"},{"type":"function","title":"Liquex.Tag.TablerowTag.render/2","doc":"","ref":"Liquex.Tag.TablerowTag.html#render/2"},{"type":"module","title":"Liquex.Tag.UnlessTag","doc":"The opposite of if – executes a block of code only if a certain condition is\nnot met.\n\n#","ref":"Liquex.Tag.UnlessTag.html"},{"type":"module","title":"Input - Liquex.Tag.UnlessTag","doc":"{% unless product.title == \"Awesome Shoes\" %}\n      These shoes are not awesome.\n    {% endunless %}\n\n#","ref":"Liquex.Tag.UnlessTag.html#module-input"},{"type":"module","title":"Output - Liquex.Tag.UnlessTag","doc":"These shoes are not awesome.\n\nThis would be the equivalent of doing the following:\n\n    {% if product.title != \"Awesome Shoes\" %}\n      These shoes are not awesome.\n    {% endif %}","ref":"Liquex.Tag.UnlessTag.html#module-output"},{"type":"extras","title":"Liquex","doc":"# Liquex\n\nA [Liquid](https://shopify.github.io/liquid/) template parser for Elixir.\n\nLiquid template renderer for Elixir with 100% compatibility with the\n[Liquid](https://shopify.github.io/liquid/) gem by [Shopify](https://www.shopify.com/).\nIf you find that this library is not byte for byte equivalent to liquid, please\n[open an issue](https://github.com/markglenn/liquex/issues).","ref":"readme.html"},{"type":"extras","title":"Installation - Liquex","doc":"The package is [available in Hex](https://hex.pm/packages/liquex) and can be installed\nby adding `liquex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:liquex, \"~> 0.13.0\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/liquex](https://hexdocs.pm/liquex).","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - Liquex","doc":"```elixir\niex> {:ok, template_ast} = Liquex.parse(\"Hello {{ name }}!\")\niex> {content, _context} = Liquex.render!(template_ast, %{\"name\" => \"World\"})\n\niex> content |> to_string()\n\"Hello World!\"\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Supported features - Liquex","doc":"Liquex is byte for byte, 100% compatible with the latest Liquid gem.","ref":"readme.html#supported-features"},{"type":"extras","title":"Lazy variables - Liquex","doc":"Liquex allows resolver functions for variables that may require some extra\nwork to generate. For example, Shopify has variables for things like\navailable products. Pulling all products every time would be too expensive\nto do on every render. Instead, it would be better to lazily pull that\ninformation as needed.\n\nInstead of adding the product list to the context variable map, you can add\na function to the variable map. If a function is accessed in the variable\nmap, it is executed.\n\n```elixir\nproducts_resolver = fn _parent -> Product.all() end\n\nwith {:ok, document} <- Liquex.parse(\"There are {{ products.size }} products\"),\n    {result, _} <- Liquex.render!(document, %{products: products_resolver}) do\n  result\nend\n\n\"There are 5 products\"\n```","ref":"readme.html#lazy-variables"},{"type":"extras","title":"Indifferent access - Liquex","doc":"By default, Liquex accesses your maps and structs that may have atom or\nstring (or other type) keys. Liquex will try a string key first. If that\nfails, it will fall back to using an atom keys.  This is similar to how\nRuby on Rails handles many of its hashes.\n\nThis allows you to pass in your structs without having to replace all your\nkeys with string keys.\n\n```elixir\niex> {:ok, template_ast} = Liquex.parse(\"Hello {{ name }}!\")\niex> {content, _context} = Liquex.render!(template_ast, %{name: \"World\"})\niex> content |> to_string()\n\"Hello World!\"\n```","ref":"readme.html#indifferent-access"},{"type":"extras","title":"Caching - Liquex","doc":"Liquex has a built in cache used specifically for the render tag currently. When\nloading a partial/sub-template using the render tag, it will try pulling from\nthe cache associated with the context.\n\nBy default, caching is disabled, but you may use the built in ETS based cache by\nconfiguring it in your context.\n\n```elixir\n:ok = Liquex.Cache.SimpleCache.init()\ncontext = Context.new(%{...}, cache: Liquex.Cache.SimpleCache)\n```\n\nThe simple cache is by definition quite simple. To use a more complete caching\nsystem, such as [Cachex](https://github.com/whitfin/cachex), you can create a\nmodule that implements the `Liquex.Cache` behaviour.\n\nThe cache system is very early on. It is expected that it will also be used to\nmemoize some of the variables within your context.","ref":"readme.html#caching"},{"type":"extras","title":"Custom filters - Liquex","doc":"Liquex contains the full suite of standard Liquid filters, but you may find that there are still\nfilters that you may want to add.\n\nLiquex supports adding your own custom filters to the render pipeline.  When creating the context\nfor the renderer, set the filter module to your own module.\n\n```elixir\ndefmodule CustomFilter do\n  # Import all the standard liquid filters\n  use Liquex.Filter\n\n  def scream(value, _), do: String.upcase(value) <> \"!\"\nend\n\ncontext = Liquex.Context.new(%{}, filter_module: CustomFilter)\n{:ok, template_ast} = Liquex.parse(\"{{'Hello World' | scream}}\"\n\n{result, _} = Liquex.render!(template_ast, context)\nresult |> to_string()\n\niex> \"HELLO WORLD!\"\n```","ref":"readme.html#custom-filters"},{"type":"extras","title":"Custom tags - Liquex","doc":"One of the strong points for Liquex is that the tag parser can be extended to support non-standard\ntags. For example, Liquid used internally for the Shopify site includes a large range of tags that\nare not supported by the base Ruby gem.  These tags could also be added to Liquex by extending the\nliquid parser.\n\n```elixir\ndefmodule CustomTag do\n  @moduledoc false\n\n  @behaviour Liquex.Tag\n\n  import NimbleParsec\n\n  @impl true\n  # Parse < >\n  def parse() do\n    text =\n      lookahead_not(string(\">>\"))\n      |> utf8_char([])\n      |> times(min: 1)\n      |> reduce({Kernel, :to_string, []})\n      |> tag(:text)\n\n    ignore(string(\"<<\"))\n    |> optional(text)\n    |> ignore(string(\">>\"))\n  end\n\n  @impl true\n  def render(contents, context) do\n    {result, context} = Liquex.render!(contents, context)\n    {[\"Custom Tag: \", result], context}\n  end\nend\n\ndefmodule CustomParser do\n  use Liquex.Parser, tags: [CustomTag]\nend\n\niex> document = Liquex.parse!(\"< >\", CustomParser)\niex> {result, _} = Liquex.render!(document, context)\niex> result |> to_string()\n\"Custom Tag: Hello World!\"\n```","ref":"readme.html#custom-tags"},{"type":"extras","title":"Deviations from original Liquid gem - Liquex","doc":"#","ref":"readme.html#deviations-from-original-liquid-gem"},{"type":"extras","title":"Whitespace is kept in empty blocks - Liquex","doc":"For performance reasons, whitespace is kept within empty blocks such as\nfor/if/unless. The liquid gem checks for \"blank\" renders and throws them away.\nInstead, we continue to use IO lists to combine the output and don't check for\nblank results to avoid too many conversions to strings.  Since Liquid is mostly\nused for whitespace agnostic documents, this seemed like a decent tradeoff. If\nyou need better whitespace control, use `{%-`, `{{-`, `-%}`, and `-}}`.","ref":"readme.html#whitespace-is-kept-in-empty-blocks"}],"content_type":"text/markdown"}